@@ -2,7 +2,7 @@ package Fl;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = '0.99.9';
+our $VERSION = '0.99.10';
 use XSLoader;
 use vars qw[@EXPORT_OK @EXPORT %EXPORT_TAGS];
 use Exporter qw[import];
@@ -25,25 +25,3 @@ $EXPORT_TAGS{'all'} = \@EXPORT_OK;    # When you want to import everything
     = sort map { m[^:(.+)] ? @{$EXPORT_TAGS{$1}} : $_ } qw[:style :default]
     if 0 && keys %EXPORT_TAGS > 1;
 1;
-__END__
-
-=pod
-
-=encoding utf-8
-
-=head1 NAME
-
-Fl - Bindings for the Stable 1.3.x Branch of the Fast Light Toolkit
-
-=head1 LICENSE
-
-Copyright (C) Sanko Robinson.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Sanko Robinson E<lt>sanko@cpan.orgE<gt>
-
-=cut
